@@ -314,6 +314,17 @@ public:
     void Print( const RENDER_SETTINGS* aSettings, const wxPoint& aOffset,
                 int aMulti, int aConvert, const LIB_SYMBOL_OPTIONS& aOpts );
 
+    /**
+     * Print just the background fills of a symbol
+     *
+     * @param aOffset - Position of symbol.
+     * @param aMulti - unit if multiple units per symbol.
+     * @param aConvert - Symbol conversion (DeMorgan) if available.
+     * @param aOpts - Drawing options
+     */
+    void PrintBackground( const RENDER_SETTINGS *aSettings, const wxPoint &aOffset, int aMulti,
+            int aConvert, const LIB_SYMBOL_OPTIONS &aOpts );
+
     /**
      * Plot lib symbol to plotter.
      * Lib Fields not are plotted here, because this plot function
@@ -612,8 +623,7 @@ public:
      *         1 if this symbol is greater than \a aRhs
      *         0 if this symbol is the same as \a aRhs
      */
-    int Compare( const LIB_SYMBOL& aRhs,
-                 LIB_ITEM::COMPARE_FLAGS aCompareFlags = LIB_ITEM::COMPARE_FLAGS::NORMAL ) const;
+    int Compare( const LIB_SYMBOL& aRhs, int aCompareFlags = 0 ) const;
 
     bool operator==( const LIB_SYMBOL* aSymbol ) const { return this == aSymbol; }
     bool operator==( const LIB_SYMBOL& aSymbol ) const
