@@ -259,15 +259,15 @@ SCH_EDIT_FRAME::SCH_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
     m_auimgr.SetManagedWindow( this );
 
     CreateInfoBar();
-    m_auimgr.AddPane( m_mainToolBar, EDA_PANE().HToolbar().Name( "MainToolbar" )
+    m_auimgr.AddPane( m_mainToolBar, EDA_PANE().HToolbar().Name( wxT( "MainToolbar" ) )
                       .Top().Layer( 6 ) );
-    m_auimgr.AddPane( m_optionsToolBar, EDA_PANE().VToolbar().Name( "OptToolbar" )
+    m_auimgr.AddPane( m_optionsToolBar, EDA_PANE().VToolbar().Name( wxT( "OptToolbar" ) )
                       .Left().Layer( 3 ) );
-    m_auimgr.AddPane( m_drawToolBar, EDA_PANE().VToolbar().Name( "ToolsToolbar" )
+    m_auimgr.AddPane( m_drawToolBar, EDA_PANE().VToolbar().Name( wxT( "ToolsToolbar" ) )
                       .Right().Layer( 2 ) );
-    m_auimgr.AddPane( GetCanvas(), EDA_PANE().Canvas().Name( "DrawFrame" )
+    m_auimgr.AddPane( GetCanvas(), EDA_PANE().Canvas().Name( wxT( "DrawFrame" ) )
                       .Center() );
-    m_auimgr.AddPane( m_messagePanel, EDA_PANE().Messages().Name( "MsgPanel" )
+    m_auimgr.AddPane( m_messagePanel, EDA_PANE().Messages().Name( wxT( "MsgPanel" ) )
                       .Bottom().Layer( 6 ) );
 
     FinishAUIInitialization();
@@ -655,6 +655,16 @@ bool SCH_EDIT_FRAME::canCloseWindow( wxCloseEvent& aEvent )
         if( symbolViewer && !symbolViewer->Close() )   // Can close modal symbol viewer?
             return false;
     }
+    else
+    {
+        auto* symbolEditor = (SYMBOL_EDIT_FRAME*) Kiway().Player( FRAME_SCH_SYMBOL_EDITOR, false );
+
+        if( symbolEditor && symbolEditor->IsSymbolFromSchematic() )
+        {
+            if( !symbolEditor->CanCloseSymbolFromSchematic( true ) )
+                return false;
+        }
+    }
 
     SIM_PLOT_FRAME* simFrame = (SIM_PLOT_FRAME*) Kiway().Player( FRAME_SIMULATOR, false );
 
@@ -836,7 +846,7 @@ void SCH_EDIT_FRAME::OnModify()
     GetCanvas()->Refresh();
     UpdateHierarchyNavigator();
 
-    if( !GetTitle().StartsWith( "*" ) )
+    if( !GetTitle().StartsWith( wxT( "*" ) ) )
         UpdateTitle();
 }
 
@@ -859,6 +869,12 @@ void SCH_EDIT_FRAME::OnUpdatePCB( wxCommandEvent& event )
         fn.SetExt( PcbFileExtension );
 
         frame = Kiway().Player( FRAME_PCB_EDITOR, true );
+
+        // If Kiway() cannot create the Pcbnew frame, it shows a error message, and
+        // frame is null
+        if( !frame )
+            return;
+
         frame->OpenProjectFiles( std::vector<wxString>( 1, fn.GetFullPath() ) );
     }
 
@@ -982,7 +998,7 @@ void SCH_EDIT_FRAME::NewProject()
         }
 
         // OpenProjectFiles() requires absolute
-        wxASSERT_MSG( create_me.IsAbsolute(), "wxFileDialog returned non-absolute path" );
+        wxASSERT_MSG( create_me.IsAbsolute(), wxT( "wxFileDialog returned non-absolute path" ) );
 
         OpenProjectFiles( std::vector<wxString>( 1, create_me.GetFullPath() ), KICTL_CREATE );
         m_mruPath = create_me.GetPath();
@@ -994,8 +1010,8 @@ void SCH_EDIT_FRAME::LoadProject()
 {
     wxString pro_dir = m_mruPath;
     wxString wildcards = AllSchematicFilesWildcard()
-                            + "|" + KiCadSchematicFileWildcard()
-                            + "|" + LegacySchematicFileWildcard();
+                            + wxT( "|" ) + KiCadSchematicFileWildcard()
+                            + wxT( "|" ) + LegacySchematicFileWildcard();
 
     wxFileDialog dlg( this, _( "Open Schematic" ), pro_dir, wxEmptyString,
                       wildcards, wxFD_OPEN | wxFD_FILE_MUST_EXIST );
@@ -1033,6 +1049,12 @@ void SCH_EDIT_FRAME::OnOpenPcbnew( wxCommandEvent& event )
             if( !frame )
             {
                 frame = Kiway().Player( FRAME_PCB_EDITOR, true );
+
+                // frame can be null if Cvpcb cannot be run. No need to show a warning
+                // Kiway() generates the error messages
+                if( !frame )
+                    return;
+
                 frame->OpenProjectFiles( std::vector<wxString>( 1, boardfn.GetFullPath() ) );
             }
 
@@ -1070,6 +1092,12 @@ void SCH_EDIT_FRAME::OnOpenCvpcb( wxCommandEvent& event )
         if( !player )
         {
             player = Kiway().Player( FRAME_CVPCB, true );
+
+            // player can be null if Cvpcb cannot be run. No need to show a warning
+            // Kiway() generates the error messages
+            if( !player )
+                return;
+
             player->Show( true );
         }
 
@@ -1339,7 +1367,7 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
 
 #ifdef PROFILE
     timer.Stop();
-    wxLogTrace( "CONN_PROFILE", "SchematicCleanUp() %0.4f ms", timer.msecs() );
+    wxLogTrace( "CONN_PROFILE", wxT( "SchematicCleanUp() %0.4f ms" ), timer.msecs() );
 #endif
 
     if( settings.m_IntersheetRefsShow )
@@ -1492,6 +1520,8 @@ void SCH_EDIT_FRAME::ShowChangedLanguage()
     // status bar
     UpdateMsgPanel();
 
+    UpdateTitle();
+
     // This ugly hack is to fix an option(left) toolbar update bug that seems to only affect
     // windows.  See https://bugs.launchpad.net/kicad/+bug/1816492.  For some reason, calling
     // wxWindow::Refresh() does not resolve the issue.  Only a resize event seems to force the
@@ -1511,7 +1541,7 @@ void SCH_EDIT_FRAME::UpdateNetHighlightStatus()
     }
     else
     {
-        SetStatusText( wxT( "" ) );
+        SetStatusText( wxEmptyString );
     }
 }
 
