@@ -449,11 +449,6 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testItemAgainstZones( BOARD_ITEM* aItem
                         const SHAPE_SEGMENT* hole = pad->GetEffectiveHoleShape();
                         int                  size = hole->GetWidth();
 
-                        // Note: drill size represents finish size, which means the actual hole
-                        // size is 2x the plating thickness larger.
-                        if( pad->GetAttribute() == PAD_ATTRIB::PTH )
-                            size += 2 * m_board->GetDesignSettings().GetHolePlatingThickness();
-
                         itemShape = std::make_shared<SHAPE_SEGMENT>( hole->GetSeg(), size );
                     }
                 }
@@ -537,7 +532,7 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testTrackClearances()
 
     reportAux( wxT( "Testing %d tracks & vias..." ), m_board->Tracks().size() );
 
-    std::map< std::pair<BOARD_ITEM*, BOARD_ITEM*>, int> checkedPairs;
+    std::map< std::pair<BOARD_ITEM*, BOARD_ITEM*>, LSET> checkedPairs;
 
     for( PCB_TRACK* track : m_board->Tracks() )
     {
@@ -570,13 +565,15 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testTrackClearances()
                         if( static_cast<void*>( a ) > static_cast<void*>( b ) )
                             std::swap( a, b );
 
-                        if( checkedPairs.count( { a, b } ) )
+                        auto it = checkedPairs.find( { a, b } );
+
+                        if( it != checkedPairs.end() && it->second.test( layer ) )
                         {
                             return false;
                         }
                         else
                         {
-                            checkedPairs[ { a, b } ] = 1;
+                            checkedPairs[ { a, b } ].set( layer );
                             return true;
                         }
                     },
