@@ -591,8 +591,13 @@ int PCB_CONTROL::DeleteItemCursor( const TOOL_EVENT& aEvent )
 
                     PCB_SELECTION_TOOL* selectionTool = m_toolMgr->GetTool<PCB_SELECTION_TOOL>();
                     selectionTool->UnbrightenItem( m_pickerItem );
-                    selectionTool->AddItemToSel( m_pickerItem, true /*quiet mode*/ );
-                    m_toolMgr->RunAction( ACTIONS::doDelete, true );
+
+                    PCB_SELECTION items;
+                    items.Add( m_pickerItem );
+
+                    EDIT_TOOL* editTool = m_toolMgr->GetTool<EDIT_TOOL>();
+                    editTool->DeleteItems( items, false );
+
                     m_pickerItem = nullptr;
                 }
 
@@ -724,6 +729,79 @@ static void pasteFootprintItemsToFootprintEditor( FOOTPRINT* aClipFootprint, BOA
 }
 
 
+void PCB_CONTROL::pruneItemLayers( std::vector<BOARD_ITEM*>& aItems )
+{
+    LSET                     enabledLayers = board()->GetEnabledLayers();
+    std::vector<BOARD_ITEM*> returnItems;
+    bool                     fpItemDeleted = false;
+
+    auto processFPItem =
+            [&]( FOOTPRINT* aFootprint, BOARD_ITEM* aItem )
+            {
+                LSET allowed = aItem->GetLayerSet() & enabledLayers;
+
+                if( allowed.any() )
+                {
+                    aItem->SetLayerSet( allowed );
+                }
+                else
+                {
+                    aFootprint->Remove( aItem );
+                    fpItemDeleted = true;
+                }
+            };
+
+    for( BOARD_ITEM* item : aItems )
+    {
+        if( item->Type() == PCB_FOOTPRINT_T )
+        {
+            FOOTPRINT* fp = static_cast<FOOTPRINT*>( item );
+
+            if( !enabledLayers.test( fp->Reference().GetLayer() ) )
+                fp->Reference().SetLayer( fp->IsFlipped() ? B_SilkS : F_SilkS );
+
+            if( !enabledLayers.test( fp->Value().GetLayer() ) )
+                fp->Value().SetLayer( fp->IsFlipped() ? B_Fab : F_Fab );
+
+            // NOTE: all traversals from the back as processFPItem() might delete the item
+
+            for( int ii = static_cast<int>( fp->Pads().size() ) - 1; ii >= 0; ii-- )
+                processFPItem( fp, fp->Pads()[ii] );
+
+            for( int ii = static_cast<int>( fp->Zones().size() ) - 1; ii >= 0; ii-- )
+                processFPItem( fp, fp->Zones()[ii] );
+
+            for( int ii = static_cast<int>( fp->GraphicalItems().size() ) - 1; ii >= 0; ii-- )
+                processFPItem( fp, fp->GraphicalItems()[ii] );
+
+            if( fp->GraphicalItems().size() || fp->Pads().size() || fp->Zones().size() )
+                returnItems.push_back( fp );
+        }
+        else
+        {
+            LSET allowed = item->GetLayerSet() & enabledLayers;
+
+            if( allowed.any() )
+            {
+                item->SetLayerSet( allowed );
+                returnItems.push_back( item );
+            }
+        }
+    }
+
+    if( ( returnItems.size() < aItems.size() ) || fpItemDeleted )
+    {
+        // We have no existing strings in 6.0 that are even remotely appropriate here, so the
+        // best we can do is show the user English and let them use Google Translate.
+        DisplayError( m_frame, wxT( "Warning: some pasted items were on layers which are not "
+                                    "present in the current board.\n"
+                                    "These items could not be pasted.\n" )  );
+    }
+
+    aItems = returnItems;
+}
+
+
 int PCB_CONTROL::Paste( const TOOL_EVENT& aEvent )
 {
     CLIPBOARD_IO pi;
@@ -813,6 +891,8 @@ int PCB_CONTROL::Paste( const TOOL_EVENT& aEvent )
 
                 delete clipBoard;
 
+                pruneItemLayers( pastedItems );
+
                 placeBoardItems( pastedItems, true, true,
                                  pasteMode == PASTE_MODE::UNIQUE_ANNOTATIONS );
             }
@@ -859,6 +939,8 @@ int PCB_CONTROL::Paste( const TOOL_EVENT& aEvent )
                 pastedItems.push_back( clipFootprint );
             }
 
+            pruneItemLayers( pastedItems );
+
             placeBoardItems( pastedItems, true, true, pasteMode == PASTE_MODE::UNIQUE_ANNOTATIONS );
             break;
         }
@@ -974,6 +1056,8 @@ int PCB_CONTROL::placeBoardItems( BOARD* aBoard, bool aAnchorAtOrigin, bool aRea
     // selection created aBoard that has the group and all descendants in it.
     moveUnflaggedItems( aBoard->Groups(), items, isNew );
 
+    pruneItemLayers( items );
+
     return placeBoardItems( items, isNew, aAnchorAtOrigin, aReannotateDuplicates );
 }
 
